<?php 
$translations = array(
	'General_Locale' => 'hu_HU.UTF-8',
	'General_TranslatorName' => 'Viktor Horvath & Mr. Balu',
	'General_TranslatorEmail' => 'fityazz@yahoo.co.uk',
	'General_EnglishLanguageName' => 'Hungarian',
	'General_OriginalLanguageName' => 'Magyar',
	'General_HelloUser' => 'Szia, %s!',
	'General_OpenSourceWebAnalytics' => 'Nyílt forráskó0dú Web Diagnosztika',
	'General_YourDashboard' => 'A TE vezérlőpultod',
	'General_API' => 'API',
	'General_Widgets' => 'Bővítmények',
	'General_Settings' => 'Beállítás',
	'General_GiveUsYourFeedback' => 'Küldj nekünk visszajelzést!',
	'General_Unknown' => 'Ismeretlen',
	'General_Required' => '%s szükséges',
	'General_Error' => 'Hiba',
	'General_Warning' => 'Figyelmeztetés',
	'General_BackToHomepage' => 'Vissza a Piwik oldalára',
	'General_Yes' => 'Igen',
	'General_No' => 'Nem',
	'General_Delete' => 'Töröl',
	'General_Edit' => 'Szerkeszt',
	'General_Ok' => 'Oké',
	'General_Close' => 'Bezár',
	'General_Logout' => 'Kilépés',
	'General_Done' => 'Kész',
	'General_LoadingData' => 'Adatok betöltése folyamatban...',
	'General_Loading' => 'Betöltés...',
	'General_ErrorRequest' => 'Hoppá-hoppá!; probléma a kérés közben, kérlek próbáld újra.',
	'General_Next' => 'Következő',
	'General_Previous' => 'Előző',
	'General_Search' => 'Keresés',
	'General_Others' => 'Mások',
	'General_Table' => 'Táblázat',
	'General_Piechart' => 'Tortadiagramm',
	'General_TagCloud' => 'SzóFelhő',
	'General_VBarGraph' => 'Függőleges diagramm',
	'General_Export' => 'Export',
	'General_ExportAsImage' => 'Export képként',
	'General_SaveImageOnYourComputer' => 'A kép gépre mentéséhez kattintson az egér jobb gombjával és válassza a "Kép mentése más néven" opciót!',
	'General_Refresh' => 'Az oldal frissítése',
	'General_Visitors' => 'Látogatók',
	'General_ColumnNbUniqVisitors' => 'Kiemelt látogatók',
	'General_ColumnNbVisits' => 'Látogatások',
	'General_ColumnNbActions' => 'Akciók',
	'General_ColumnMaxActions' => 'Egy látogató maximális akciói',
	'General_ColumnSumVisitLength' => 'Látogatók által eltöltött összes idő (másodpercben)',
	'General_ColumnLabel' => 'Címke',
	'General_ColumnActionsPerVisit' => 'Akciók/látogatás',
	'General_ColumnAvgTimeOnSite' => 'Átlagidő az oldalon',
	'General_ColumnBounceRate' => 'Lepattanó látogatók',
	'General_ColumnPageviews' => 'Oldal-megtekintések',
	'General_ColumnUniquePageviews' => 'Kiemelt oldal-megtekintések',
	'General_ColumnValuePerVisit' => 'Érték/látogatók',
	'General_ColumnVisitsWithConversions' => 'látogatók with Conversions',
	'General_Save' => 'Mentés',
	'General_Website' => 'Weboldal',
	'General_NoDataForGraph' => 'Nincs adat ehhez a grafikonhoz',
	'General_NoDataForTagCloud' => 'Nincs adat ehhez a SzóFelhőhöz.',
	'General_DisplayNormalTable' => 'Normál táblázat',
	'General_DisplayMoreData' => 'Több adat',
	'General_PiwikIsACollaborativeProject' => '%s Piwik %s egy együttműködésen alapuló projekt és még Béta állaptú. %s Ha segíteni akarsz nekünk, kérünk %s vedd fel a kapcsolatot velünk!%s.',
	'General_YouAreCurrentlyViewingDemoOfPiwik' => 'Jelenleg a Demó verziót nézed %s; %töltsd le%s a teljes verziót! Check out %s',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Elérhető az új Piwik verzió: %s. %s Kérem frissítse most!%s (ézze meg %s a változások listáját%s).',
	'General_BackToPiwik' => 'Vissza a Piwik-re',
	'General_ShortMonth_1' => 'Jan',
	'General_ShortMonth_2' => 'Feb',
	'General_ShortMonth_3' => 'Már',
	'General_ShortMonth_4' => 'Ápr',
	'General_ShortMonth_5' => 'Máj',
	'General_ShortMonth_6' => 'Jún',
	'General_ShortMonth_7' => 'Júl',
	'General_ShortMonth_8' => 'Aug',
	'General_ShortMonth_9' => 'Sze',
	'General_ShortMonth_10' => 'Okt',
	'General_ShortMonth_11' => 'Nov',
	'General_ShortMonth_12' => 'Dec',
	'General_LongMonth_1' => 'Január',
	'General_LongMonth_2' => 'Február',
	'General_LongMonth_3' => 'Március',
	'General_LongMonth_4' => 'Április',
	'General_LongMonth_5' => 'Május',
	'General_LongMonth_6' => 'Június',
	'General_LongMonth_7' => 'Július',
	'General_LongMonth_8' => 'Augusztus',
	'General_LongMonth_9' => 'Szeptember',
	'General_LongMonth_10' => 'Október',
	'General_LongMonth_11' => 'November',
	'General_LongMonth_12' => 'December',
	'General_ShortDay_1' => 'Hét',
	'General_ShortDay_2' => 'Ked',
	'General_ShortDay_3' => 'Sze',
	'General_ShortDay_4' => 'Csü',
	'General_ShortDay_5' => 'Pén',
	'General_ShortDay_6' => 'Szo',
	'General_ShortDay_7' => 'Vas',
	'General_LongDay_1' => 'Hétfő',
	'General_LongDay_2' => 'Kedd',
	'General_LongDay_3' => 'Szerda',
	'General_LongDay_4' => 'Csütörtök',
	'General_LongDay_5' => 'Péntek',
	'General_LongDay_6' => 'Szombat',
	'General_LongDay_7' => 'Vasárnap',
	'CorePluginsAdmin_Plugins' => 'Bővítmények',
	'CorePluginsAdmin_PluginsManagement' => 'Bővítménykezelő',
	'CorePluginsAdmin_MainDescription' => 'A bővítmények kiterjesztik a Piwik funkcióit. Ha egyszer a bővítményt telepítetted, itt aktiválhatod vagy kikapcsolhatod.',
	'CorePluginsAdmin_Plugin' => 'Bővítmény',
	'CorePluginsAdmin_Version' => 'Verzió',
	'CorePluginsAdmin_Description' => 'Leírás',
	'CorePluginsAdmin_Status' => 'Állapot',
	'CorePluginsAdmin_Action' => 'Akció',
	'CorePluginsAdmin_PluginHomepage' => 'Bővítmény honlapja',
	'CorePluginsAdmin_Activated' => 'Aktívált',
	'CorePluginsAdmin_Active' => 'Aktív',
	'CorePluginsAdmin_Inactive' => 'Kikapcsolt',
	'CorePluginsAdmin_ActivatedHelp' => 'Ezt a bővítményt nem lehet kikapcsolni!',
	'CorePluginsAdmin_Deactivate' => 'Kikapcsol',
	'CorePluginsAdmin_Activate' => 'Aktivál',
	'CorePluginsAdmin_MenuPlugins' => 'Bővítmények',
	'API_QuickDocumentation' => '<h2>API gyors dokumentáció</h2><p>Ha nincs még semmi forgalmad<a href=\'misc/generateVisits.php\' target=_blank> generálj némi adatot </a> Ehhez használd a látogató generátor szkriptet.</p><p>Kipróbálhatsz különböző formátumokat, melyek elérhetőek minden metódushoz .Nagyon egyszerű elérni bármilyen adatot a Piwik-től!</p><p><b>További információért nézd meg az <a href=\'http://dev.piwik.org/trac/wiki/API\'>hivatalos API Documentációt</a> vagy a <a href=\'http://dev.piwik.org/trac/wiki/API/Reference\'>API Ajánlást</a>.</b></P><h2>Felhasználó azonosító</h2><p>Ha meg akarsz <b>hívni bármilyen adatot a szkriptedbe, táblázatodba, stb. </b>  A következő paramétert kell hozzáadnod <code><u>&token_auth=%s</u></code> az API-hoz, hogy meghívja az URL-t melynek hitelesítésre van szüksége.</p><p>Ez a hitelesítő Token titkos mint a felhasználóneved, vagy jelszavad <b>Ne oszd meg senkivel!</p>',
	'API_LoadedAPIs' => 'Sikeresen betöltődött %s API',
	'CoreHome_NoPrivileges' => 'Beléptél mint \'%s\' de úgy tűnik nincs jogod a Piwik beállításához<br />Kérj a Piwik adminisztrátorodtól legalább egy \'megnézős\' hozzáférést a weboldalhoz.',
	'CoreHome_JavascriptDisabled' => 'A javascriptek futtatásának engedélyezve kell lennie, hogy használhasd a Piwik-et normál nézetben<br />Hovatovább úgy tűnik a Javascriptek le vannak tiltva, vagy nem támogatja a böngésződ<br />Hogy használhasd a normál nézetet, engedélyezd a Böngésződ beállításánál a Javascriptek futtatását, vagy %1spróbáld újra%2s.<br />',
	'CoreHome_TableNoData' => 'Nincs adat ehhez a táblázathoz.',
	'CoreHome_CategoryNoData' => 'Nincs adat ebben a kategóriában. Próbáld a  "Tartalmazza a teljes populációt".',
	'CoreHome_ShowJSCode' => 'Mutasd a javascript kódot a beillesztéshez',
	'CoreHome_IncludeAllPopulation_js' => 'Tartalmazza a teljes populációt',
	'CoreHome_ExcludeLowPopulation_js' => 'Kivéve alacsony populáció',
	'CoreHome_PageOf_js' => '%s of %s',
	'CoreHome_Loading_js' => 'Betöltés...',
	'CoreHome_LocalizedDateFormat' => '%A %d %B %Y',
	'CoreHome_PeriodDay' => 'Nap',
	'CoreHome_PeriodWeek' => 'Hét',
	'CoreHome_PeriodMonth' => 'Hónap',
	'CoreHome_PeriodYear' => 'Év',
	'CoreHome_PeriodDays' => 'napok',
	'CoreHome_PeriodWeeks' => 'hetek',
	'CoreHome_PeriodMonths' => 'hónapok',
	'CoreHome_PeriodYears' => 'évek',
	'CoreHome_DaySu_js' => 'V',
	'CoreHome_DayMo_js' => 'H',
	'CoreHome_DayTu_js' => 'K',
	'CoreHome_DayWe_js' => 'Sze',
	'CoreHome_DayTh_js' => 'Cs',
	'CoreHome_DayFr_js' => 'P',
	'CoreHome_DaySa_js' => 'Szo',
	'CoreHome_ShortDay_1_js' => 'Vas',
	'CoreHome_ShortDay_2_js' => 'Hét',
	'CoreHome_ShortDay_3_js' => 'Ked',
	'CoreHome_ShortDay_4_js' => 'Sze',
	'CoreHome_ShortDay_5_js' => 'Csü',
	'CoreHome_ShortDay_6_js' => 'Pén',
	'CoreHome_ShortDay_7_js' => 'Szo',
	'CoreHome_LongDay_1_js' => 'Vasámap',
	'CoreHome_LongDay_2_js' => 'Hétfö',
	'CoreHome_LongDay_3_js' => 'Kedd',
	'CoreHome_LongDay_4_js' => 'Szerda',
	'CoreHome_LongDay_5_js' => 'Csütörtök',
	'CoreHome_LongDay_6_js' => 'Péntek',
	'CoreHome_LongDay_7_js' => 'Szombat',
	'CoreHome_ShortMonth_1_js' => 'Jan',
	'CoreHome_ShortMonth_2_js' => 'Feb',
	'CoreHome_ShortMonth_3_js' => 'Már',
	'CoreHome_ShortMonth_4_js' => 'Ápr',
	'CoreHome_ShortMonth_5_js' => 'Máj',
	'CoreHome_ShortMonth_6_js' => 'Jún',
	'CoreHome_ShortMonth_7_js' => 'Júl',
	'CoreHome_ShortMonth_8_js' => 'Aug',
	'CoreHome_ShortMonth_9_js' => 'Szep',
	'CoreHome_ShortMonth_10_js' => 'Okt',
	'CoreHome_ShortMonth_11_js' => 'Nov',
	'CoreHome_ShortMonth_12_js' => 'Dec',
	'CoreHome_MonthJanuary_js' => 'Január',
	'CoreHome_MonthFebruary_js' => 'Február',
	'CoreHome_MonthMarch_js' => 'Március',
	'CoreHome_MonthApril_js' => 'Április',
	'CoreHome_MonthMay_js' => 'Május',
	'CoreHome_MonthJune_js' => 'Június',
	'CoreHome_MonthJuly_js' => 'Július',
	'CoreHome_MonthAugust_js' => 'Augusztus',
	'CoreHome_MonthSeptember_js' => 'Szeptember',
	'CoreHome_MonthOctober_js' => 'Október',
	'CoreHome_MonthNovember_js' => 'November',
	'CoreHome_MonthDecember_js' => 'December',
	'CoreUpdater_UpdateTitle' => 'Piwik &rsaquo; Frissítés',
	'CoreUpdater_DatabaseUpgradeRequired' => 'Adatbázisfrissítés szükséges',
	'CoreUpdater_YourDatabaseIsOutOfDate' => 'A Piwik adatbázisod túl régi, frissítened kell mielőtt folytatnád!',
	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'Piwik adatbázisa frissülni fog %s verzióról az új %s verzióra.',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'A következő bővítmények lesznek frissítve: %s.',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'Az adatbázis frissítése eltart egy ideig, kérünk várj türelemmel!',
	'CoreUpdater_UpgradePiwik' => 'Piwik frissítése',
	'CoreUpdater_HelpMessageContent' => 'Nézd meg a %s Piwik GYIK-et %s, melyből megtudhatod a frissítés folyamán fellépő leggyakoribb hibákat. %s Kérdezd a rendszergazdád - Talán Ő tud segíteni, hisz a rendszergazda áll közvetlen kapcsolatban a szervereddel, és segíthet megérteni a MySQL beállításokkal kapcsolatos problémád!',
	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Kritikus hiba a frissítés folyamán!',
	'CoreUpdater_HelpMessageIntroductionWhenError' => 'Feljebb láthatod a FŐ HIBÁT! Ez talán segít megérteni az okot, de ha további segítségre van szükséged, kérünk:',
	'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'A frissítés sikeres volt, azonban ezek történtek a frissítés alatt. A részletekért kérünk olvasd el a fenti leírást! További segítségért:',
	'CoreUpdater_UpgradeComplete' => 'Frissítés kész!',
	'CoreUpdater_WarningMessages' => 'Figyelmeztető üzenet:',
	'CoreUpdater_ErrorDuringPluginsUpdates' => 'Hiba a bővítmény frissítése közben:',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'Automatikusan kikapcsoltuk a következő bővítményeket: %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'A Piwik sikeresen frissült!',
	'CoreUpdater_ContinueToPiwik' => 'Tovább a Piwik-hez',
	'CoreUpdater_UpdateAutomatically' => 'Automatikus frissítés',
	'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => 'A Piwik-nek van egy új verziója, ami rendelkezésre áll frissítéshez',
	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => 'Frissítheti automatokusan %s verzióra vagy töltse le a csomagot és telepítse kézzel:',
	'CoreUpdater_DownloadX' => '%s letöltése',
	'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'A Piwik egy kattintásos frissítését törölték. Ha nem tudod kijavítani a fenti hibaüzenetben kapott hibát, ajánlott, hogy kézzel frissítsd a Piwik-et. %s Olvasd el a %s frissítési dokumentációt %s, hogy elindíthasd!',
	'CoreUpdate_DownloadingUpdateFromX' => 'Frissítés letöltése innen: %s',
	'CoreUpdate_UnpackingTheUpdate' => 'Frissítés kicsomagolása',
	'CoreUpdater_VerifyingUnpackedFiles' => 'Kicsomagolt fájlok ellenőrzése',
	'CoreUpdater_CreatingBackupOfConfigurationFile' => 'Konfigurációs fájl biztonsági mentésének készítése: %s',
	'CoreUpdater_InstallingTheLatestVersion' => 'A legfrissebb verzó telepítése',
	'CoreUpdater_PiwikUpdatedSuccessfully' => 'A Piwik frissítése sikeresen megtörtént!',
	'Actions_Actions' => 'Akciók',
	'Actions_SubmenuPages' => 'Oldalak',
	'Actions_SubmenuOutlinks' => 'Külső linkek',
	'Actions_SubmenuDownloads' => 'Letöltések',
	'Actions_ColumnClicks' => 'Kattintások',
	'Actions_ColumnUniqueClicks' => 'Egyedi kattintások',
	'Actions_ColumnDownloads' => 'Letöltések',
	'Actions_ColumnUniqueDownloads' => 'Egyedi letöltések',
	'Actions_ColumnPageName' => 'Oldal neve',
	'Actions_ColumnClickedURL' => 'Kattintott URL',
	'Actions_ColumnDownloadURL' => 'Letöltött URL',
	'Dashboard_Dashboard' => 'Vezérlőpult',
	'Dashboard_AddWidget' => 'Kiegészítő hozzáadása...',
	'Dashboard_DeleteWidgetConfirm' => 'Biztosan törölni akarod ezt a kiegészítőt a vezérlőpultról?',
	'Dashboard_SelectWidget' => 'Válaszd ki a kiegészítőt, hogy hozzáadhasd a vezérlőpulthoz!',
	'Dashboard_AddPreviewedWidget_js' => 'Add a megtekintett kiegészítőt a vezérlőpultodhoz',
	'Dashboard_WidgetPreview_js' => 'Kiegészítő előnézete',
	'Dashboard_Close_js' => 'Bezár',
	'Dashboard_TitleWidgetInDashboard_js' => 'A kiegészítő már a vezérlőpulton van',
	'Dashboard_TitleClickToAdd_js' => 'Kattints a vezérlőpulthoz való hozzáadáshoz',
	'Dashboard_LoadingWidget_js' => 'Kiegészítő betöltése, kérünk várj...',
	'Dashboard_WidgetNotFound_js' => 'A kiegészítő nem található',
	'Referers_Referers' => 'Hivatkozások',
	'Referers_SearchEngines' => 'Keresőmotorok',
	'Referers_Keywords' => 'Kulcsszavak',
	'Referers_DirectEntry' => 'közvetlen hozzáférés',
	'Referers_Websites' => 'Weboldalak',
	'Referers_Campaigns' => 'Kampányok',
	'Referers_MetricsFromRefererTypeGraphLegend' => '%1s (ebből: %2s)',
	'Referers_Evolution' => 'Változás a periódusban',
	'Referers_Type' => 'Hivatkozás típusa',
	'Referers_ColumnRefererType' => 'Hivatkozás típusa',
	'Referers_ColumnSearchEngine' => 'Keresőmotor',
	'Referers_ColumnWebsite' => 'Weboldal',
	'Referers_ColumnWebsitePage' => 'Weboldal oldala',
	'Referers_ColumnKeyword' => 'Kulcsszó',
	'Referers_ColumnCampaign' => 'Kampány',
	'Referers_DetailsByRefererType' => 'Hivatkozás típusának részletei',
	'Referers_TypeDirectEntries' => '%s közvetlen hozzáférés',
	'Referers_TypeSearchEngines' => '%s a keresőmotoroktól',
	'Referers_TypeWebsites' => '%s a weboldalaktól',
	'Referers_TypeCampaigns' => '%s a kampányoktól',
	'Referers_Distinct' => 'Hivatkozás típusának különböző hivatkozásai',
	'Referers_DistinctSearchEngines' => 'különböző keresőmotor',
	'Referers_DistinctKeywords' => 'különböző kulcsszó',
	'Referers_DistinctCampaigns' => 'különböző kampány',
	'Referers_DistinctWebsites' => 'különböző weboldal',
	'Referers_UsingNDistinctUrls' => ' (%2s különböző URL-t használ)',
	'Referers_SubmenuEvolution' => 'Változás',
	'Referers_SubmenuSearchEngines' => 'Keresőmotorok és kulcsszavak',
	'Referers_SubmenuWebsites' => 'Weboldalak',
	'Referers_SubmenuCampaigns' => 'Kampányok',
	'Referers_WidgetKeywords' => 'Kulcsszavak listája',
	'Referers_WidgetCampaigns' => 'Kampányok listája',
	'Referers_WidgetExternalWebsites' => 'Külső weboldalak listája',
	'Referers_WidgetSearchEngines' => 'Legjobb keresőmotorok',
	'Referers_WidgetOverview' => 'Áttekintés',
	'UserSettings_VisitorSettings' => 'Látogató beállításai',
	'UserSettings_BrowserFamilies' => 'Böngészőcsaládok',
	'UserSettings_Browsers' => 'Böngészők',
	'UserSettings_Plugins' => 'Bővítmények',
	'UserSettings_Configurations' => 'Konfigurációk',
	'UserSettings_OperatingSystems' => 'Operációs rendszerek',
	'UserSettings_Resolutions' => 'Felbontások',
	'UserSettings_WideScreen' => 'Képernyő oldalarányai',
	'UserSettings_ColumnBrowserFamily' => 'Böngészőcsalád',
	'UserSettings_ColumnBrowser' => 'Böngésző',
	'UserSettings_ColumnPlugin' => 'Bővítmény',
	'UserSettings_ColumnConfiguration' => 'Konfiguráció',
	'UserSettings_ColumnOperatingSystem' => 'Operációs rendszer',
	'UserSettings_ColumnResolution' => 'Felbontás',
	'UserSettings_ColumnTypeOfScreen' => 'Képernyő típusa',
	'UserSettings_WidgetResolutions' => 'Képernyőfelbontások',
	'UserSettings_WidgetBrowsers' => 'Látogatók böngészője',
	'UserSettings_WidgetPlugins' => 'Bővítmények listája',
	'UserSettings_WidgetWidescreen' => 'Normál/szélesvásznú',
	'UserSettings_WidgetBrowserFamilies' => 'Böngészők család szerint',
	'UserSettings_WidgetOperatingSystems' => 'Operációs rendszerek',
	'UserSettings_WidgetGlobalVisitors' => 'Globális látogatói beállítások',
	'UserSettings_SubmenuSettings' => 'Beállítások',
	'UserCountry_Country' => 'Ország',
	'UserCountry_Continent' => 'Kontinens',
	'UserCountry_DistinctCountries' => '%s különböző ország',
	'UserCountry_SubmenuLocations' => 'Helyek',
	'UserCountry_WidgetContinents' => 'Látogatók kontinensei',
	'UserCountry_WidgetCountries' => 'Látogatók országai',
	'UserCountry_country_ac' => 'Ascension-sziget',
	'UserCountry_country_ad' => 'Andorra',
	'UserCountry_country_ae' => 'Egyesült Arab Emirátusok',
	'UserCountry_country_af' => 'Afganisztán',
	'UserCountry_country_ag' => 'Antigua és Barbuda',
	'UserCountry_country_ai' => 'Anguilla',
	'UserCountry_country_al' => 'Albánia',
	'UserCountry_country_am' => 'Arménia',
	'UserCountry_country_an' => 'Holland Antillák',
	'UserCountry_country_ao' => 'Angola',
	'UserCountry_country_aq' => 'Északi-sark',
	'UserCountry_country_ar' => 'Argentína',
	'UserCountry_country_as' => 'Amerikai Szamoa',
	'UserCountry_country_at' => 'Ausztria',
	'UserCountry_country_au' => 'Ausztrália',
	'UserCountry_country_aw' => 'Aruba',
	'UserCountry_country_az' => 'Azerbajdzsán',
	'UserCountry_country_ba' => 'Bosznia-Hercegovina',
	'UserCountry_country_bb' => 'Barbadosz',
	'UserCountry_country_bd' => 'Banglades',
	'UserCountry_country_be' => 'Belgium',
	'UserCountry_country_bf' => 'Burkina Faso',
	'UserCountry_country_bg' => 'Bulgária',
	'UserCountry_country_bh' => 'Bahrain',
	'UserCountry_country_bi' => 'Burundi',
	'UserCountry_country_bj' => 'Benin',
	'UserCountry_country_bm' => 'Bermuda',
	'UserCountry_country_bn' => 'Bruneo',
	'UserCountry_country_bo' => 'Bolívia',
	'UserCountry_country_br' => 'Brazília',
	'UserCountry_country_bs' => 'Bahama-szigetek',
	'UserCountry_country_bt' => 'Bhután',
	'UserCountry_country_bv' => 'Bouvet-sziget',
	'UserCountry_country_bw' => 'Botswana',
	'UserCountry_country_by' => 'Fehéroroszország',
	'UserCountry_country_bz' => 'Belize',
	'UserCountry_country_ca' => 'Kanada',
	'UserCountry_country_cc' => 'Kókusz (Keeling)-szigetek',
	'UserCountry_country_cd' => 'Kongói Demokratikus Köztársaság',
	'UserCountry_country_cf' => 'Közép-Afrikai Köztársaság',
	'UserCountry_country_cg' => 'Kongó',
	'UserCountry_country_ch' => 'Svájc',
	'UserCountry_country_ci' => 'Elefántcsontpart',
	'UserCountry_country_ck' => 'Cook-szigetek',
	'UserCountry_country_cl' => 'Chile',
	'UserCountry_country_cm' => 'Kamerun',
	'UserCountry_country_cn' => 'Kína',
	'UserCountry_country_co' => 'Kolumbia',
	'UserCountry_country_cr' => 'Costa Rica',
	'UserCountry_country_cs' => 'Szerbia és Montenegró',
	'UserCountry_country_cu' => 'Kuba',
	'UserCountry_country_cv' => 'Zöld-foki Köztársaság',
	'UserCountry_country_cx' => 'Karácsony-sziget',
	'UserCountry_country_cy' => 'Ciprus',
	'UserCountry_country_cz' => 'Csehország',
	'UserCountry_country_de' => 'Németország',
	'UserCountry_country_dj' => 'Dzsibuti',
	'UserCountry_country_dk' => 'Dánia',
	'UserCountry_country_dm' => 'Dominika',
	'UserCountry_country_do' => 'Dominikai Köztársaság',
	'UserCountry_country_dz' => 'Algéria',
	'UserCountry_country_ec' => 'Ekvádor',
	'UserCountry_country_ee' => 'Észtország',
	'UserCountry_country_eg' => 'Egyiptom',
	'UserCountry_country_eh' => 'Nyugat-Szahara',
	'UserCountry_country_er' => 'Eritrea',
	'UserCountry_country_es' => 'Spanyolország',
	'UserCountry_country_et' => 'Etiópia',
	'UserCountry_country_fi' => 'Finnország',
	'UserCountry_country_fj' => 'Fidzsi-szigetek',
	'UserCountry_country_fk' => 'Falkland-szigetek (Malvinas)',
	'UserCountry_country_fm' => 'Mikronéziai Szövetségi Államok',
	'UserCountry_country_fo' => 'Feröer-szigetek',
	'UserCountry_country_fr' => 'Franciaország',
	'UserCountry_country_ga' => 'Gabon',
	'UserCountry_country_gd' => 'Grenada',
	'UserCountry_country_ge' => 'Grúzia',
	'UserCountry_country_gf' => 'Francia Guyana',
	'UserCountry_country_gg' => 'Guernsey',
	'UserCountry_country_gh' => 'Ghána',
	'UserCountry_country_gi' => 'Gibraltár',
	'UserCountry_country_gl' => 'Grönland',
	'UserCountry_country_gm' => 'Gambia',
	'UserCountry_country_gn' => 'Guinea',
	'UserCountry_country_gp' => 'Kis-Antillák', //Guadeloupe
	'UserCountry_country_gq' => 'Egyenlítői Guinea',
	'UserCountry_country_gr' => 'Görögország',
	'UserCountry_country_gs' => 'Dél-Georgia és Déli-Sandwich-szigetek',
	'UserCountry_country_gt' => 'Guatemala',
	'UserCountry_country_gu' => 'Guam',
	'UserCountry_country_gw' => 'Bissau-Guinea',
	'UserCountry_country_gy' => 'Guyana',
	'UserCountry_country_hk' => 'Hongkong',
	'UserCountry_country_hm' => 'Heard-sziget és McDonald-szigetek',
	'UserCountry_country_hn' => 'Hondurász',
	'UserCountry_country_hr' => 'Horvátország',
	'UserCountry_country_ht' => 'Haiti',
	'UserCountry_country_hu' => 'Magyarország',
	'UserCountry_country_id' => 'Indonézia',
	'UserCountry_country_ie' => 'Írország',
	'UserCountry_country_il' => 'Izrael',
	'UserCountry_country_im' => 'Man-sziget',
	'UserCountry_country_in' => 'India',
	'UserCountry_country_io' => 'Brit Indiai-óceáni Terület',
	'UserCountry_country_iq' => 'Irak',
	'UserCountry_country_ir' => 'Iráni Iszlám Köztársaság',
	'UserCountry_country_is' => 'Izland',
	'UserCountry_country_it' => 'Olaszország',
	'UserCountry_country_je' => 'Jersey',
	'UserCountry_country_jm' => 'Jamaika',
	'UserCountry_country_jo' => 'Jordánia',
	'UserCountry_country_jp' => 'Japán',
	'UserCountry_country_ke' => 'Kenya',
	'UserCountry_country_kg' => 'Kirgizisztán',
	'UserCountry_country_kh' => 'Kambodzsa',
	'UserCountry_country_ki' => 'Kiribati',
	'UserCountry_country_km' => 'Comoros',
	'UserCountry_country_kn' => 'Szent Kitts és Nevis',
	'UserCountry_country_kp' => 'Koreai Népi Demokratikus Köztársaság',
	'UserCountry_country_kr' => 'Koreai Köztársaság',
	'UserCountry_country_kw' => 'Kuwait',
	'UserCountry_country_ky' => 'Kajmán-szigetek',
	'UserCountry_country_kz' => 'Kazahsztán',
	'UserCountry_country_la' => 'Laosz',
	'UserCountry_country_lb' => 'Libanon',
	'UserCountry_country_lc' => 'Szent Lucia',
	'UserCountry_country_li' => 'Liechtenstein',
	'UserCountry_country_lk' => 'Srí Lanka',
	'UserCountry_country_lr' => 'Libéria',
	'UserCountry_country_ls' => 'Lesothó',
	'UserCountry_country_lt' => 'Litvánia',
	'UserCountry_country_lu' => 'Luxemburg',
	'UserCountry_country_lv' => 'Lettország',
	'UserCountry_country_ly' => 'Líbia',
	'UserCountry_country_ma' => 'Marokkó',
	'UserCountry_country_mc' => 'Monaco',
	'UserCountry_country_md' => 'Moldova Köztársaság',
	'UserCountry_country_mg' => 'Madagaszkár',
	'UserCountry_country_mh' => 'Marshall-szigetek',
	'UserCountry_country_mk' => 'Macedónia',
	'UserCountry_country_ml' => 'Mali',
	'UserCountry_country_mm' => 'Mianmar',
	'UserCountry_country_mn' => 'Mongólia',
	'UserCountry_country_mo' => 'Makaó',
	'UserCountry_country_mp' => 'Északi-Mariana-szigetek',
	'UserCountry_country_mq' => 'Martinique',
	'UserCountry_country_mr' => 'Mauritánia',
	'UserCountry_country_ms' => 'Montserrat',
	'UserCountry_country_mt' => 'Málta',
	'UserCountry_country_mu' => 'Mauritius',
	'UserCountry_country_mv' => 'Maldív-szigetek',
	'UserCountry_country_mw' => 'Malawi',
	'UserCountry_country_mx' => 'Mexikó',
	'UserCountry_country_my' => 'Malajzia',
	'UserCountry_country_mz' => 'Mozambik',
	'UserCountry_country_na' => 'Namíbia',
	'UserCountry_country_nc' => 'Új-Kaledónia',
	'UserCountry_country_ne' => 'Niger',
	'UserCountry_country_nf' => 'Norfolk-szigetek',
	'UserCountry_country_ng' => 'Nigéria',
	'UserCountry_country_ni' => 'Nicaragua',
	'UserCountry_country_nl' => 'Hollandia',
	'UserCountry_country_no' => 'Norvégia',
	'UserCountry_country_np' => 'Nepál',
	'UserCountry_country_nr' => 'Nauru',
	'UserCountry_country_nu' => 'Niue',
	'UserCountry_country_nz' => 'Új-Zéland',
	'UserCountry_country_om' => 'Omán',
	'UserCountry_country_pa' => 'Panama',
	'UserCountry_country_pe' => 'Peru',
	'UserCountry_country_pf' => 'Francia Polinézia',
	'UserCountry_country_pg' => 'Pápua Új Guinea',
	'UserCountry_country_ph' => 'Fülöp-szigetek',
	'UserCountry_country_pk' => 'Pakisztán',
	'UserCountry_country_pl' => 'Lengyelország',
	'UserCountry_country_pm' => 'Szent Pierre és Miquelon',
	'UserCountry_country_pn' => 'Pitcairn-szigetek',
	'UserCountry_country_pr' => 'Puerto Rico',
	'UserCountry_country_ps' => 'Palesztin Terület',
	'UserCountry_country_pt' => 'Portugália',
	'UserCountry_country_pw' => 'Palau',
	'UserCountry_country_py' => 'Paraguay',
	'UserCountry_country_qa' => 'Katar',
	'UserCountry_country_re' => 'Réunion',
	'UserCountry_country_ro' => 'Románia',
	'UserCountry_country_ru' => 'Oroszország',
	'UserCountry_country_rs' => 'Szerbia',
	'UserCountry_country_rw' => 'Ruanda',
	'UserCountry_country_sa' => 'Szaúd-Arábia',
	'UserCountry_country_sb' => 'Salamon-szigetek',
	'UserCountry_country_sc' => 'Seychelle-szigetek',
	'UserCountry_country_sd' => 'Szudán',
	'UserCountry_country_se' => 'Svédország',
	'UserCountry_country_sg' => 'Színgapur',
	'UserCountry_country_sh' => 'Szent Ilona sziget',
	'UserCountry_country_si' => 'Szlovénia',
	'UserCountry_country_sj' => 'Svalbard',
	'UserCountry_country_sk' => 'Szlovákia',
	'UserCountry_country_sl' => 'Sierra Léone',
	'UserCountry_country_sm' => 'San Marino',
	'UserCountry_country_sn' => 'Szenegál',
	'UserCountry_country_so' => 'Szomália',
	'UserCountry_country_sr' => 'Suriname',
	'UserCountry_country_st' => 'Sao Tomé és Principe',
	'UserCountry_country_su' => 'Szovjetunió',
	'UserCountry_country_sv' => 'El Salvador',
	'UserCountry_country_sy' => 'Szíriai Arab Köztársaság',
	'UserCountry_country_sz' => 'Szváziföld',
	'UserCountry_country_tc' => 'Turks- és Caicos-szigetek',
	'UserCountry_country_td' => 'Csád',
	'UserCountry_country_tf' => 'Francia déli területek',
	'UserCountry_country_tg' => 'Togo',
	'UserCountry_country_th' => 'Taiföld',
	'UserCountry_country_tj' => 'Tadzsikisztán',
	'UserCountry_country_tk' => 'Tokelau',
	'UserCountry_country_tm' => 'Türkmenisztán',
	'UserCountry_country_tn' => 'Tunézia',
	'UserCountry_country_to' => 'Tonga',
	'UserCountry_country_tp' => 'Kelet-Timor',
	'UserCountry_country_tr' => 'Törökország',
	'UserCountry_country_tt' => 'Trinidad és Tobago',
	'UserCountry_country_tv' => 'Tuvalu',
	'UserCountry_country_tw' => 'Taiwan',
	'UserCountry_country_tz' => 'Tanzánia',
	'UserCountry_country_ua' => 'Ukrajna',
	'UserCountry_country_ug' => 'Uganda',
	'UserCountry_country_uk' => 'Egyesült Királyság',
	'UserCountry_country_gb' => 'Nagy-Britannia',
	'UserCountry_country_um' => 'Egyesült Államok külső szigetei',
	'UserCountry_country_us' => 'Amerikai Egyesült Államok',
	'UserCountry_country_uy' => 'Uruguay',
	'UserCountry_country_uz' => 'Üzbegisztán',
	'UserCountry_country_va' => 'Vatikán',
	'UserCountry_country_vc' => 'Szent Vincent és Grenadine-szigetek',
	'UserCountry_country_ve' => 'Venezuela',
	'UserCountry_country_vg' => 'Virgin-szigetek (Brit)',
	'UserCountry_country_vi' => 'Virgin-szigetek (USA)',
	'UserCountry_country_vn' => 'Vietnám',
	'UserCountry_country_vu' => 'Vanuatu',
	'UserCountry_country_wf' => 'Wallis- és Futuna-szigetek',
	'UserCountry_country_ws' => 'Samoa',
	'UserCountry_country_ye' => 'Jemen',
	'UserCountry_country_yt' => 'Mayotte',
	'UserCountry_country_yu' => 'Jugoszlávia',
	'UserCountry_country_za' => 'Dél-Afrikai Köztársaság',
	'UserCountry_country_zm' => 'Zambia',
	'UserCountry_country_zr' => 'Zaire',
	'UserCountry_country_zw' => 'Zimbabwe',
	'UserCountry_continent_eur' => 'Európa',
	'UserCountry_continent_afr' => 'Afrika',
	'UserCountry_continent_asi' => 'Ázsia',
	'UserCountry_continent_ams' => 'Dél- és Közép-Amerika',
	'UserCountry_continent_amn' => 'Észak-Amerika',
	'UserCountry_continent_oce' => 'Óceánia',
	'VisitsSummary_NbVisits' => '%s látogatás',
	'VisitsSummary_NbUniqueVisitors' => '%s kiemelt látogatás',
	'VisitsSummary_NbActions' => '%s akció (oldal megtekintések)',
	'VisitsSummary_TotalTime' => '%s a látogatók által eltöltött összes idő',
	'VisitsSummary_MaxNbActions' => 'maximum %s akció egy látogatáskor',
	'VisitsSummary_NbVisitsBounced' => 'A látogatók %s-a elment (elhagyta a weboldalt egy oldal megtekintése után)',
	'VisitsSummary_EvolutionOverLastPeriods' => 'Változás az utóbbi időegységben (%s)',
	'VisitsSummary_Report' => 'Riport',
	'VisitsSummary_GenerateTime' => '%s másodperc az oldal generálásához',
	'VisitsSummary_GenerateQueries' => '%s kérés végrehajtva',
	'VisitsSummary_WidgetLastVisits' => 'Utolsó látogatások grafikonja',
	'VisitsSummary_WidgetVisits' => 'Látogatások áttekintése',
	'VisitsSummary_WidgetLastVisitors' => 'Utolsó kiemelt látogatók grafikonja',
	'VisitsSummary_WidgetOverviewGraph' => 'Áttekintés grafikonnal',
	'VisitsSummary_SubmenuOverview' => 'Áttekintés',
	'VisitFrequency_Evolution' => 'Változás a periódus alatt',
	'VisitFrequency_ColumnReturningVisits' => 'Visszatérő látogatók',
	'VisitFrequency_ColumnActionsByReturningVisits' => 'Visszatérő látogatók akciói',
	'VisitFrequency_ColumnMaximumActionsByAReturningVisit' => 'Visszatérő látogató maximális akciói',
	'VisitFrequency_ColumnTotalTimeSpentByReturningVisits' => 'Visszatérő látogatók teljes eltöltött ideje (másodpercben)',
	'VisitFrequency_ColumnBounceRateForReturningVisits' => 'Visszatérő látogatók kilépési hányada',
	'VisitFrequency_ReturnVisits' => '%s visszatérő látogató',
	'VisitFrequency_ReturnActions' => '%s akció visszatérő látogatóktól',
	'VisitFrequency_ReturnMaxActions' => 'maximálisan %s akció egy visszatérő látogatótól',
	'VisitFrequency_ReturnTotalTime' => '%s a visszatérő látogatók teljes eltöltött ideje',
	'VisitFrequency_ReturnBounceRate' => '%s-ban a visszatérő látogató kilépett (a weboldalt elhagyta egyetlen oldal megtekintése után)',
	'VisitFrequency_WidgetOverview' => 'Gyakoriság áttekintése',
	'VisitFrequency_WidgetGraphReturning' => 'Visszatérő látogatások diagramja',
	'VisitFrequency_SubmenuFrequency' => 'Gyakoriság',
	'VisitTime_LocalTime' => 'Látogatások/helyi idő',
	'VisitTime_ServerTime' => 'Látogatások/szerveridő',
	'VisitTime_ColumnServerTime' => 'Szerver idő',
	'VisitTime_ColumnLocalTime' => 'Helyi idő',
	'VisitTime_WidgetLocalTime' => 'Látogatások helyi idő szerint',
	'VisitTime_WidgetServerTime' => 'Látogatások szerveridő szerint',
	'VisitTime_SubmenuTimes' => 'Idő',
	'VisitTime_NHour' => '%s ó',
	'VisitorInterest_VisitsPerDuration' => 'Látogatók/látogatás időtartama',
	'VisitorInterest_VisitsPerNbOfPages' => 'Látogatások/oldalak száma',
	'VisitorInterest_ColumnVisitDuration' => 'Látogatás időtartama',
	'VisitorInterest_ColumnPagesPerVisit' => 'Oldalak/látogatás',
	'VisitorInterest_WidgetLengths' => 'Látogatások időtartama',
	'VisitorInterest_WidgetPages' => 'Oldalak/látogatás',
	'VisitorInterest_SubmenuFrequencyLoyalty' => 'Gyakoriság és hűség',
	'VisitorInterest_PlusXMin' => '%s perc',
	'VisitorInterest_BetweenXYMinutes' => '%1s-%1s perc',
	'VisitorInterest_OnePage' => '1 oldal',
	'VisitorInterest_NPages' => '%s oldal',
	'VisitorInterest_BetweenXYSeconds' => '%1s-%2s s',
	'Login_LoginPasswordNotCorrect' => 'Felhasználó/jelszó páros nem megfelelő',
	'Login_Login' => 'Felhasználó',
	'Login_Password' => 'Jelszó',
	'Login_LoginOrEmail' => 'Belépés vagy e-mail',
	'Login_LogIn' => 'Bejelentkezés',
	'Login_Logout' => 'Kijelentkezés',
	'Login_LostYourPassword' => 'Elfelejtetted a jelszavad?',
	'Login_RemindPassword' => 'Jelszó emlékeztető',
	'Login_PasswordReminder' => 'Kérlek add meg a felhasználó neved vagy e-mail címed. Küldünk egy új jelszót levélben!',
	'Login_InvalidUsernameEmail' => 'Helytelen felhasználó és/vagy e-mail cím',
	'Login_MailTopicPasswordRecovery' => 'Jelszó újrakérése',
	'Login_MailPasswordRecoveryBody' => 'Hello %1s, \n\n Az új jelszavad: %2s \n\n Mostmár be tudsz lépni itt: %3s',
	'Login_PasswordSent' => 'A jelszó elküldve, kérjük ellenőrizd a postaládád.',
	'Login_ContactAdmin' => 'Lehetséges ok: talán a szolgáltatód tiltja a levélküldés funkciót. <br />Kérjük lépj kapcsolatba a Piwik rendszergazdáddal.',
	'UsersManager_UsersManagement' => 'Felhasználói menedzsment',
	'UsersManager_UsersManagementMainDescription' => 'Új felhasználó hozzáadása, vagy a meglévők beállítása. Feljebb beállíthatod a jogosultságaikat.',
	'UsersManager_ManageAccess' => 'Hozzáférés beállítása',
	'UsersManager_MainDescription' => 'Döntsd el, melyik felhasználónak milyen Piwik hozzáférést biztosítasz a weboldaladon. Vagy beállíthatod az összes weboldalhoz az összes jogosultságot egyszerre.',
	'UsersManager_Sites' => 'Oldalak',
	'UsersManager_AllWebsites' => 'Minden weboldal',
	'UsersManager_ApplyToAllWebsites' => 'Érvényesítés minden weboldalra',
	'UsersManager_User' => 'Felhasználó',
	'UsersManager_PrivNone' => 'Nincs belépési jogod',
	'UsersManager_PrivView' => 'Nézet',
	'UsersManager_PrivAdmin' => 'Admin',
	'UsersManager_ChangeAllConfirm' => 'Biztosan meg akarod változtatni \'%s\' jogosultságot az összes weboldalon?',
	'UsersManager_Login' => 'Felhasználónév',
	'UsersManager_Password' => 'Jelszó',
	'UsersManager_Email' => 'E-mail',
	'UsersManager_Alias' => 'Álnév',
	'UsersManager_Token' => 'token_auth',
	'UsersManager_Edit' => 'Szerkeszt',
	'UsersManager_AddUser' => 'Új felhasználó hozzáadása',
	'UsersManager_MenuUsers' => 'Felhasználók',
	'UsersManager_DeleteConfirm_js' => 'Biztosan törölni akarod a következő felhasználót: %s?',
	'UsersManager_ExceptionLoginExists' => '\'%s\' nevű felhasználó már létezik.',
	'UsersManager_ExceptionEmailExists' => '\'%s\' e-mail címmel már létezik felhasználó.',
	'UsersManager_ExceptionInvalidLoginFormat' => 'A felhasználónév csak betűket (%s-%s), számokat, vagy a következő karaktereket tartalmazhatja: \'_\' vagy \'-\' vagy \'.\'',
	'UsersManager_ExceptionInvalidPassword' => 'A jelszó hossza minimum 6, maximum 26 karakter lehet',
	'UsersManager_ExceptionInvalidEmail' => 'Az e-mail cím nem megfelelő formátumú',
	'UsersManager_ExceptionDeleteDoesNotExist' => '\'%s\' felhasználó nem létezik, ezért nem törölhető!',
	'UsersManager_ExceptionAdminAnonymous' => 'Nem adhatsz \'admin\' jogosultságot \'anonymous\' felhasználónak.',
	'UsersManager_ExceptionEditAnonymous' => 'Az anonymous felhasználó nem szerkeszthető vagy törölhető. Ezt a Piwik használja a be nem lépett felhasználó azonosítására. Például, publikussá teheted a statisztikád egyszerű \'nézet\' módban az \'anonymous\' felhasználók számára.',
	'UsersManager_ExceptionSuperUser' => 'A kért felhasználó egy Rendszergazda és így nem lehet lekérdezni, szerkeszteni vagy törölni az API-n keresztül. Csak kézzel tudod szerkeszteni a Rendszergazda opcióit a Piwik konfigurációs fájlodban.',
	'UsersManager_ExceptionUserDoesNotExist' => '\'%s\' felhasználó nem létezik.',
	'UsersManager_ExceptionAccessValues' => 'A belépési paraméternek meg kell felelnie a következő értékek egyikének : [ %s ]',
	'SitesManager_Sites' => 'oldalak',
	'SitesManager_WebsitesManagement' => 'Weboldal menedzsment',
	'SitesManager_MainDescription' => 'Az analitikai riportodhoz szükség van weboldalakra! Adj meg, frissíts vagy törölj weboldalakat, és mutasd a JavaScript-et az oldaladba való beillesztéshez.',
	'SitesManager_JsCode' => 'JavaScript kód',
	'SitesManager_JsCodeHelp' => 'Itt van a JavaScript kód, amit az összes oldaladnak tartalmaznia kell',
	'SitesManager_ShowJsCode' => 'Mutasd a kódot',
	'SitesManager_NoWebsites' => 'Nincs egyetlen weboldalad sem!',
	'SitesManager_AddSite' => 'Adj hozzá új oldalt',
	'SitesManager_Id' => 'Azonosító',
	'SitesManager_Name' => 'Név',
	'SitesManager_Urls' => 'URL-ek',
	'SitesManager_MenuSites' => 'Oldalak',
	'SitesManager_DeleteConfirm_js' => 'Biztosan törölni akarod a következő oldalt %s?',
	'SitesManager_ExceptionDeleteSite' => 'Nem törölheted ezt az oldalt, amíg ez az egyetlen regisztrált weboldalad. Előbb adj meg egy újat és azután töröld ezt!',
	'SitesManager_ExceptionNoUrl' => 'Meg kell adnod legalább egy URL-t az oldalhoz.',
	'SitesManager_ExceptionEmptyName' => 'Az oldal neve nem lehet üres.',
	'SitesManager_ExceptionInvalidUrl' => 'Az url \'%s\' nem valódi URL.',
	'Installation_Installation' => 'Telepítés',
	'Installation_InstallationStatus' => 'Telepítés állapota',
	'Installation_PercentDone' => '%s %% kész',
	'Installation_NoConfigFound' => 'Megpróbálsz belépni a Piwik oldalra, de a konfigurációs fájl nem található.<br /><b>&nbsp;&nbsp;&raquo; Most tudod <a href=\'index.php\'>installálni a Piwik-et </a></b><br /><small>Ha már installáltad a Piwik-et korábban és voltak már táblák az adatbázisodban, ne aggódj, tudod használni azokat a táblákat és megtathatod a meglévő adataidat!</small>',
	'Installation_MysqlSetup' => 'Mysql adatbázis beállítás',
	'Installation_MysqlErrorConnect' => 'Hiba a MySQL adatbázishoz való csatlakozásnál!!!',
	'Installation_JsTag' => 'Javascript cimke',
	'Installation_JsTagHelp' => '<p>Hogy számlálni tudd a látogatóid, be kell illesztened az alábbi javascript kódot minden weboldaladba.</p><p>Az oldalaidnak nem muszáj PHP-ben készülnie,a Piwik működik minden oldaltípussal (például: HTML, ASP, Perl vagy minden más nyelven írt oldallal).</p><p>Itt a kód amit be kell illesztened: (másold ki és illeszd be minden oldaladba) </p>',
	'Installation_Congratulations' => 'Gratulálunk',
	'Installation_CongratulationsHelp' => '<p>Gratulálunk! A Piwik telepítése kész!.</p><p>Bizonyosodj meg róla, hogy a javascript be van illesztve minden oldaladba, így nincs más hátra mint várnod az első látogatóid!</p>',
	'Installation_ContinueToPiwik' => 'Tovább a Piwik-hez',
	'Installation_SetupWebsite' => 'Weboldal beállítása',
	'Installation_SetupWebsiteError' => 'Hiba a weboldal hozzáadása közben!',
	'Installation_GeneralSetup' => 'Általános beállítás',
	'Installation_GeneralSetupSuccess' => 'Az általános beállítások sikeresen megtörténtek',
	'Installation_SuperUserLogin' => 'Rendszergazda felhasználó',
	'Installation_Password' => 'Jelszó',
	'Installation_PasswordRepeat' => 'Jelszó (ismét)',
	'Installation_Email' => 'E-mail',
	'Installation_SecurityNewsletter' => 'Küldjön e-mailt ujabb verziójú Piwik frissítések és biztonsági riasztások esetén',
	'Installation_CommunityNewsletter' => 'Küldjön e-mailt fejlesztési frissítésekről (új bővítmény, új tulajdonság, stb.)',
	'Installation_PasswordDoNotMatch' => 'jelszó nem megfelelő',
	'Installation_SubmitGo' => 'Mehet!',
	'Installation_SystemCheck' => 'rendszer ellenőrzés',
	'Installation_SystemCheckPhp' => 'PHP verzió',
	'Installation_SystemCheckPdo' => 'Pdo kiterjesztés',
	'Installation_SystemCheckPdoMysql' => 'Pdo_Mysql kiterjesztes',
	'Installation_SystemCheckPdoError' => 'engedélyezned kell a PDO és PDO_MYSQL kiterjesztéseket a php.ini fájlodban.',
	'Installation_SystemCheckPdoHelp' => 'Windows szerveren add a következő sorokat a php.ini-hez, vagy vedd ki a ";" jelet a sor elejéről a fájlban %s <br /><br />Linux szerveren a php-t a következő opciókkal fordítsd %s A php.ini fájlhoz add hozzá a következő sorokat %s<br /><br />További információ a <a style="color:red" href="http://php.net/pdo">PHP weboldal</a>on.',
	'Installation_SystemCheckWriteDirs' => 'Könyvtárak írási jogosultsággal',
	'Installation_SystemCheckWriteDirsHelp' => 'Hogy kijavítsd a hibát Linux rendszereden, próbáld a következő parancso(ka)t',
	'Installation_SystemCheckMemoryLimit' => 'Memória minimum',
	'Installation_SystemCheckMemoryLimitHelp' => 'Egy nagyforgalmú weboldalon az archiválási folyamathoz több memória kell, mint a jelenleg engedélyezett.<br />Nézd meg a "directive memory_limit"-et a  php.ini fájlodban, ha szükséges.',
	'Installation_SystemCheckGD' => 'GD &gt; 2.x (graphics)',
	'Installation_SystemCheckGDHelp' => 'A buborékok (kis grafikonok) nem fognak működni.',
	'Installation_SystemCheckTimeLimit' => 'set_time_limit() engedélyezett',
	'Installation_SystemCheckTimeLimitHelp' => 'Egy nagyforgalmú weboldalon az archiválási folyamat végrehajtásához több idő kell, mint a jelenleg engedélyezett.<br />Nézd meg a "directive_max_execution_time"-ot a  php.ini fájlodban ha szükséges.',
	'Installation_SystemCheckMail' => 'mail() engedélyezett',
	'Installation_SystemCheckError' => 'Hiba áll fenn! - ki kell javítani mielőtt folytatnád',
	'Installation_SystemCheckWarning' => 'A Piwik működni fog normálisan, de talán néhány tulajdonság hiányozni fog',
	'Installation_Tables' => 'Táblák elkészítése',
	'Installation_TablesWithSameNamesFound' => 'Néhány táblának %s az adatbázisodban %s ugyanaz a neve, mint amilyet a Piwik megpróbál létrehozni.',
	'Installation_TablesFound' => 'A következő táblák találhatók az adatbázisban',
	'Installation_TablesWarningHelp' => 'Válaszd a meglévő adatbázis táblák használatát vagy válaszd az új telepítést a meglévő adatbázisod törléséhez',
	'Installation_TablesReuse' => 'Meglévő táblák használata',
	'Installation_TablesDelete' => 'Észlelt táblák törlése',
	'Installation_TablesDeletedSuccess' => 'Meglévő Piwik táblák sikeresen törölve!',
	'Installation_TablesCreatedSuccess' => 'Táblák sikeresen létrehozva!',
	'Installation_DatabaseCreatedSuccess' => 'Adatbázis %s sikeresen létrehozva!',
	'Installation_GoBackAndDefinePrefix' => 'Lépj vissza és add meg a Piwik táblák előtagját!',
	'Installation_ConfirmDeleteExistingTables' => 'Biztos vagy benne, hogy törölni akarod a táblákat: %s az adatbázisodból? FIGYELEM: A TÁBLÁK ADATAI NEM ÁLLÍTHATÓK VISSZA!',
	'Installation_Welcome' => 'Üdvözöllek!',
	'Installation_WelcomeHelp' => '<p>A Piwik egy nyílt forráskódú web analitikai szoftver, mellyel könnyedén szerezhetsz információkat weboldalad látogatottságáról.</p><p>A telepítési folyamat %s könnyű lépésből áll és kb. 5 percet vesz igénybe.</p>',
	'Installation_ErrorInvalidState' => 'Hiba: úgy tűnik, hogy megpróbálod kihagyni a telepítési eljárás egy lépését vagy a cookie-k le vannak tiltva vagy a Piwik konfigurációs fájlját már létrehoztad. %s Engedélyezd a cookie-kat %s lépj vissza %s a telepítés első oldalára %s.',
	'Provider_WidgetProviders' => 'Szolgáltatók',
	'Provider_ColumnProvider' => 'Szolgáltató',
	'Provider_SubmenuLocationsProvider' => 'Hely és szolgáltató',
	'Goals_ColumnConversions' => 'Konvertálás',
	'Goals_ColumnConversionRate' => 'Konvertálási hányad',
	'Goals_ColumnRevenue' => 'Pénzügy',
	'DBStats_DatabaseUsage' => 'Adatbázis használat',
	'DBStats_MainDescription' => 'A Piwik eltárolja az összes web analitikai adatát egy Mysql adatbázisban. Jelenleg, a Piwik táblázatok használatban %s.',
	'DBStats_Table' => 'Táblázat',
	'DBStats_RowNumber' => 'Sorszám',
	'DBStats_DataSize' => 'Adat méret',
	'DBStats_IndexSize' => 'Index méret',
	'DBStats_TotalSize' => 'Teljes méret',
	'TranslationsAdmin_MenuTranslations' => 'Fordítások',
	'TranslationsAdmin_MenuLanguages' => 'Nyelvek',
	'TranslationsAdmin_Plugin' => 'Bővítmény',
	'TranslationsAdmin_Definition' => 'Meghatározás',
	'TranslationsAdmin_DefaultString' => 'Alapértelmezett oszlop (Angol)',
	'TranslationsAdmin_TranslationString' => 'Fordítási oszlop (jelenlegi nyelv: %s)',
	'TranslationsAdmin_Translations' => 'Fordítások',
	'TranslationsAdmin_FixPermissions' => 'Kérlek állítsd be a fájlrendszer jogosultságokat',
	'TranslationsAdmin_AvailableLanguages' => 'Elérhető nyelvek',
	'TranslationsAdmin_AddLanguage' => 'Adj hozzá nyelvet',
	'TranslationsAdmin_LanguageCode' => 'Nyelvi kód',
	'TranslationsAdmin_Export' => 'Nyelv exportálása',
	'TranslationsAdmin_Import' => 'Nyelv importálása',
);
